SupadartGenerator class

Constructors

SupadartGenerator({required String clientExtension, required String storageClientExtension, required List<DartClass> dartClasses, required String modelExports, required String enums, required bool isDart, required bool needsIntl, required bool needsDartConvert, required bool needsDurationFromString, required bool needsGeometryFromJson, required YamlMap? mappings, required bool isPostGIS, required Set<String> jsonbImports})

Properties

clientExtension → String
final
dartClasses → List<DartClass>
final
enums → String
final
hashCode → int
The hash code for this object.
no setterinherited
isDart → bool
final
isPostGIS → bool
final
jsonbImports → Set<String>
final
mappings → YamlMap?
final
modelExports → String
final
needsDartConvert → bool
final
needsDurationFromString → bool
final
needsGeometryFromJson → bool
final
needsIntl → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageClientExtension → String
final

Methods

generateClassesSingleFile() → List<GeneratedFile>
generateDartModelFilesSeparated() → List<GeneratedFile>
getSupadartHeader(bool isSingleFile) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited