Bucket class

Constructors

Bucket({required String id, required String name, required String owner, required String createdAt, required String updatedAt, required bool public, int? fileSizeLimit, List<String>? allowedMimeTypes})
const
Bucket.fromJson(Map<String, dynamic> json)

Properties

allowedMimeTypes → List<String>?
final
createdAt → String
final
fileSizeLimit → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
owner → String
final
public → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited