JsonbModelConfig class

Configuration for mapping a JSONB column to a custom Dart model

Constructors

JsonbModelConfig({required String schema, required String tableName, required String columnName, required String dartType, required String importPath, bool isArray = false})

Properties

columnName → String
final
dartType → String
final
hashCode → int
The hash code for this object.
no setterinherited
importPath → String
final
isArray → bool
final
lookupKey → String
Returns the lookup key for this config (schema.table.column)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String
final
tableName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited