DatabaseSwagger class

Constructors

DatabaseSwagger(List<Table> tables, {Schemas schemas = Schemas.defaults, Map<String, List<String>> enums = const {}, List<String> warnings = const []})
DatabaseSwagger.fromJson(Map<String, dynamic> json, Map<String, List<String>> configEnums, bool jsonbToDynamic, {Map<String, JsonbModelConfig>? jsonbModels})
Parses the PostgREST schema of public. See DatabaseSwagger.fromSchemas.
factory
DatabaseSwagger.fromSchemas(Map<String, Map<String, dynamic>> specs, Map<String, List<String>> configEnums, bool jsonbToDynamic, {Map<String, JsonbModelConfig>? jsonbModels})
Parses the PostgREST schema of each database schema in specs, keyed by schema name. The first is the primary schema. configEnums are the enums from supadart.yaml, keyed by type name, which is taken to be in the primary schema unless qualified (inventory.status).
factory

Properties

enums → Map<String, List<String>>
Values of each enum, keyed by schema.type and sorted by it. Values read from the schema take precedence over the config.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemas → Schemas
final
tables → List<Table>
Tables and views of every schema, in schema order.
final
warnings → List<String>
Problems with the enum config worth telling the user about.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited