enums property

Map<String, List<String>> enums
final

Values of each enum in the public schema, keyed by type name and sorted by it. Values read from the schema take precedence over the config.

Implementation

final Map<String, List<String>> enums;