Table class

Constructors

Table({required String name, required List<String> requiredFields, required Map<String, Column> columns})
Table.fromJson(String name, Map<String, dynamic> json, Map<String, List<String>> mapOfEnums, bool jsonbToDynamic, {Map<String, JsonbModelConfig>? jsonbModels})
factory

Properties

columns → Map<String, Column>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
requiredFields → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited