Column class
Constructors
-
Column({required String postgresFormat, required String dbColName, required String camelColName, required List<
String> enumValues, required bool jsonbToDynamic, String? userType, String? userTypeDartName, dynamic hasDefaultValue, String? description, int? maxLength, bool isPrimaryKey = false, bool isSerialType = false, bool isInRequiredColumn = false, JsonbModelConfig? jsonbModelConfig}) -
Column.fromJson(String colName, Map<
String, dynamic> json, List<String> parentTableRequiredFields, Map<String, List< enums, {bool jsonbToDynamic = false, Schemas schemas = Schemas.defaults, String? schema, String? tableName, Map<String> >String, JsonbModelConfig> ? jsonbModels}) -
factory
Properties
- camelColName → String
-
final
- dartType → String
-
no setter
- dbColName → String
-
final
- description → String?
-
final
- enumDartType → String
-
The Dart enum this column holds, or its element type for an array.
no setter
-
enumValues
→ List<
String> -
final
- hasDefaultValue → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isArray → bool
-
no setter
- isEnum → bool
-
no setter
- isInRequiredColumn → bool
-
final
- isNullable → bool
-
no setter
- isPrimaryKey → bool
-
final
- isRequired → bool
-
no setter
- isRequiredInInsert → bool
-
no setter
- isSerialType → bool
-
final
- isTypedJsonb → bool
-
Returns true if this column is a JSONB with a custom typed model
no setter
- isUnresolvedUserType → bool
-
True for a user-defined type in a generated schema with no known enum
values (an enum used only in array columns, a domain, a composite type,
or an extension type such as citext). These are mapped to String.
no setter
- jsonbModelConfig → JsonbModelConfig?
-
final
- jsonbToDynamic → bool
-
final
- maxLength → int?
-
final
- nullableDartType → String
-
dartType made nullable.
dynamicalready admits null, so it is left as is rather than emitting the redundantdynamic?.no setter - postgresFormat → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userType → String?
-
schema.typewhen the column holds a user-defined type, else null.final - userTypeDartName → String?
-
The Dart name of userType, e.g.
MOODorINVENTORY_MOOD.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited