DatabaseSwagger class

Constructors

DatabaseSwagger(Map<String, Table> definitions, {Map<String, List<String>> enums = const {}, List<String> warnings = const []})
DatabaseSwagger.fromJson(Map<String, dynamic> json, Map<String, List<String>> configEnums, bool jsonbToDynamic, {Map<String, JsonbModelConfig>? jsonbModels})
Parses the PostgREST schema. configEnums are the enums from supadart.yaml, keyed by type name with or without a public. prefix.
factory

Properties

definitions → Map<String, Table>
final
enums → Map<String, List<String>>
Values of each enum in the public schema, keyed by type name and sorted by it. Values read from the schema take precedence over the config.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warnings → List<String>
Problems with the enum config worth telling the user about.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited